@@ -1,8 +1,8 @@
 from django.core.exceptions import ValidationError
 from django.forms import Form, ModelForm, TextInput, Select, DateInput, NumberInput, CharField, RadioSelect, ChoiceField
-from phonenumbers import is_valid_number, parse, NumberParseException, PhoneNumber
+from phonenumbers import is_valid_number, parse, NumberParseException
 
-from django_user_email_extension.models import User, Address
+from django_user_email_extension.models import User, UserAddress
 
 
 class TokenForm(Form):
@@ -12,6 +12,8 @@ class TokenForm(Form):
 
 class PhoneNumberVerificationForm(Form):
     """
+    although this is a Form and not a ModelForm, an instance (PhoneNumber) is passed to init,
+    as this form used to create phone numbers, but used separated fields
     bootstrap ready form
     """
     country_code = CharField(widget=TextInput(attrs={'class': 'form-control'}),
@@ -22,20 +24,9 @@ class PhoneNumberVerificationForm(Form):
         # initial=sms will set checked radio button to 'sms' value
         widget=RadioSelect(attrs={'class': 'form-check-input'}), initial='sms', required=True)
 
-    # override init function, so form will also be able to get a 'phone' key,
-    def __init__(self, *args, **kwargs):
-        # get PhoneNumberField object value passed to form if any
-        phone_number_instance = kwargs.pop("phone", None)
-
-        if isinstance(phone_number_instance, PhoneNumber):
-            # set initial
-            kwargs.update(initial={
-                # 'field': 'value'
-                'country_code': phone_number_instance.country_code,
-                'phone_number': phone_number_instance.national_number,
-            })
-
-        super(PhoneNumberVerificationForm, self).__init__(*args, **kwargs)
+    # this form should also get 'instance'
+    def __init__(self, instance, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     def clean_phone_number(self):
         phone_number = self.cleaned_data['phone_number']
@@ -65,23 +56,42 @@ class PhoneNumberVerificationForm(Form):
             self.add_error('phone_number', e)
 
 
-class AddressForm(ModelForm):
+class UserAddressForm(ModelForm):
     """
     bootstrap ready form
     """
 
     class Meta:
-        model = Address
+        model = UserAddress
         exclude = ['timezone']
         widgets = {
+            'first_name': TextInput(attrs={'class': 'form-control'}),
+            'last_name': TextInput(attrs={'class': 'form-control'}),
             'street_name': TextInput(attrs={'class': 'form-control'}),
             'street_number': TextInput(attrs={'class': 'form-control'}),
             'city': TextInput(attrs={'class': 'form-control'}),
             'state': TextInput(attrs={'class': 'form-control'}),
             'country': Select(attrs={'class': 'form-control'}),
             'zip_code': NumberInput(attrs={'class': 'form-control'}),
+            'phone_number': Select(attrs={'class': 'form-control'}),
+            'notes': TextInput(attrs={'class': 'form-control'}),
         }
 
+        fields = [
+            'first_name', 'last_name',
+            'street_name', 'street_number', 'city', 'state', 'country', 'zip_code',
+            'phone_number', 'notes',
+        ]
+
+    # this form should also get 'user' instance
+    def __init__(self, user, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.instance.user = user
+
+        # since 'phone_number' field is a foreign key to UserPhoneNumber model, for will allow to choose from all users,
+        # make sure the 'phone_number' will have only current users phone numbers
+        self.fields['phone_number'].queryset = user.get_all_phone_numbers()
+
     def clean(self):
         # empty clean function so model will not block a user of attempt to add an already existing address
         return self.cleaned_data
